%for a discussion of the model being solved here, see 
%'Solution and Analysis of a Simple Dynamic General Equilibrium Model: a
%Tutorial'
%with unit = 0, the first model, with a stationary technology shock, is
%analyzed.
%with unit = 1, the second model, the one with a unit root technology
%shock, is analyzed.
%in both cases, the model is first solved and impulse response functions
%are computed for two values of sigmaa.

clear
close all
beta=1.03^(-.25);
alpha=.36;
delta=.02;
rho=0.5;
epsilon=.015/4;
gamma=10;
sigmaa1=.1;
sigmaa2=10000;


unit = 1;
if unit == 0
    
    [A,B,Kb,c,f3,f21,f23,f22] = solveneoclassical(beta,alpha,epsilon,delta,sigmaa1,gamma,rho,1);
    [A1,B1,Kb1,c1,ff3,ff21,ff23,ff22] = solveneoclassical(beta,alpha,epsilon,delta,sigmaa2,gamma,rho,0);
    
elseif unit == 1
    
    [A,B,Kb,c,ap] = solveneoclassicalunit(beta,alpha,epsilon,delta,sigmaa1,gamma,rho);    
    [A1,B1,Kb1,c1,ap1] = solveneoclassicalunit(beta,alpha,epsilon,delta,sigmaa2,gamma,rho); 

end

T=200;
eps(1)=.01;
z(1)=B*eps(1);
z1(1)=B1*eps(1);
invss=(1-(1-delta)*exp(-epsilon))*Kb;
gnpss=(exp(-epsilon)*Kb)^alpha;
conss=gnpss-invss;

for ii = 2:T
    
    eps(ii)=rho*eps(ii-1);
    z(ii)=A*z(ii-1)+B*eps(ii);
    z1(ii)=A1*z1(ii-1)+B1*eps(ii);
    
end

if min(z) < -1 | min(z1) < -1
    error('fatal (neoclassical) capital stock negative')
end

if unit == 0

    inv(1)=(B*eps(1))/delta;
    inv1(1)=(B1*eps(1))/delta;

    ut(1)=-(f23*epsilon/f22)*eps(1)-1;
    ut1(1)=-(ff23*epsilon/ff22)*eps(1)-1;
    conhat(1)=((f3*epsilon-Kb*B)/c)*eps(1);
    conhat1(1)=((ff3*epsilon-Kb*B1)/c)*eps(1);
    
    cap(1)=z(1);
    cap1(1)=z1(1);
    
    gnphat(1)=(conss/gnpss)*conhat(1)+(invss/gnpss)*inv(1);
    gnphat1(1)=(conss/gnpss)*conhat1(1)+(invss/gnpss)*inv1(1);   
    
    for ii = 2:T
        inv(ii)=((A-(1-delta))*z(ii-1)+B*eps(ii))/delta;
        inv1(ii)=((A1-(1-delta))*z1(ii-1)+B1*eps(ii))/delta;
        ut(ii)=-(f21*Kb/f22)*z(ii-1)-(f23*epsilon/f22)*eps(ii) -1;
        ut1(ii)=-(ff21*Kb/ff22)*z1(ii-1)-(ff23*epsilon/ff22)*eps(ii) -1;
        conhat(ii)=(((1/beta)-A)*Kb/c)*z(ii-1)+((f3*epsilon-Kb*B)/c)*eps(ii);
        conhat1(ii)=(((1/beta)-A1)*Kb/c)*z1(ii-1)+((ff3*epsilon-Kb*B1)/c)*eps(ii);
        cap(ii)=z(ii);
        cap1(ii)=z1(ii);
        gnphat(ii)=(conss/gnpss)*conhat(ii)+(invss/gnpss)*inv(ii);
        gnphat1(ii)=(conss/gnpss)*conhat1(ii)+(invss/gnpss)*inv1(ii);
    end

elseif unit == 1
    
    cst=1-(1-delta)*exp(-epsilon);
    cum(1)=eps(1);
    
    for ii = 2:T
        cum(ii)=cum(ii-1)+eps(ii);
    end
    
    inv(1)=cum(1)+((B+(1-delta)*exp(-epsilon))*eps(1))/cst;
    inv1(1)=cum(1)+((B1+(1-delta)*exp(-epsilon))*eps(1))/cst;
    [u] = getuunit(alpha,eps(1)+epsilon,ap,sigmaa1,Kb);
    ut(1)=u-1;
    
    
    cap(1)=cum(1)+z(1);
    chat(1)=getconhatunit(0,z(1),eps(1),Kb,c,alpha,epsilon,delta);
    conhat(1)=cum(1)+chat(1);
    
    cap1(1)=cum(1)+z1(1);
    chat1(1)=getconhatunit(0,z1(1),eps(1),Kb,c,alpha,epsilon,delta);
    conhat1(1)=cum(1)+chat1(1);
        
    yhat(1)=(conss/gnpss)*conhat(1)+(invss/gnpss)*inv(1);
    yhat1(1)=(conss/gnpss)*conhat1(1)+(invss/gnpss)*inv1(1);   
    
    gnphat(1)=yhat(1);
    gnphat1(1)=yhat1(1);
        
    for ii = 2:T
        inv(ii)=cum(ii)+((A-(1-delta)*exp(-epsilon))*z(ii-1)+(B+(1-delta)*exp(-epsilon))*eps(ii))/cst;
        inv1(ii)=cum(ii)+((A1-(1-delta)*exp(-epsilon))*z1(ii-1)+(B1+(1-delta)*exp(-epsilon))*eps(ii))/cst;
        [u] = getuunit(alpha,eps(ii)+epsilon,ap,sigmaa1,Kb*(z(ii-1)+1));
        ut(ii)=u-1;
        cap(ii)=cum(ii)+z(ii);
        chat(ii)=getconhatunit(z(ii-1),z(ii),eps(ii),Kb,c,alpha,epsilon,delta);
        conhat(ii)=cum(ii)+chat(ii);
        
        [u] = getuunit(alpha,eps(ii)+epsilon,ap1,sigmaa2,Kb1*(z1(ii-1)+1));
        ut1(ii)=u-1;
        cap1(ii)=cum(ii)+z1(ii);        
        chat1(ii)=getconhatunit(z1(ii-1),z1(ii),eps(ii),Kb,c,alpha,epsilon,delta);
        conhat1(ii)=cum(ii)+chat1(ii);
        
        gnphat(ii)=(conss/gnpss)*conhat(ii)+(invss/gnpss)*inv(ii);
        gnphat1(ii)=(conss/gnpss)*conhat1(ii)+(invss/gnpss)*inv1(ii);
    end
    
end

str=['Model Parameter values: \rho = ',num2str(rho),', \beta = ', ...
    num2str(beta),', \delta = ',num2str(delta),', \gamma = ', ...
    num2str(gamma),', solid line: \sigma _{a} = ',num2str(sigmaa1),', starred line: \sigma _{a} = ',num2str(sigmaa2)];

pic=1;
plotout(T,cap,cap1,conhat,conhat1,inv,inv1,ut,ut1,gnphat,gnphat1,cum,cum,str,pic);

