function [k,Y,C,eps,z,cons,inv,util,gnp,speed] = solvemodel(alpha,beta,epsilon,delta,T,sigma_a,sigma,rho)

%this is where the steady state capital stock, k, is computed. In addition,
%b, the parameter in the capital utilization adjustment cost function is
%computed here
k=(alpha*epsilon/((1/beta)-(1-delta)))^(1/(1-alpha));
b=(1/beta)-(1-delta);

%this is where the formulas for the log-linear expansion of the capital 
%utilization first order condition appear
cc=alpha*epsilon*k^alpha;
deruu=[(alpha-1)*cc (alpha-1-sigma_a)*cc cc];

%this is where the log-linear expansion of the capital utilization fonc is
%obtained numerically....(first, verify that the euler equation is zero at
%the steady state)
x(1)=k;
x(2)=1;
x(3)=epsilon;
[vu] = Vuanswer(x,sigma_a,alpha,b);
if abs(vu) > .1e-9
    error('fatal (hmk1answer) static euler equation not satisfied')
end
[QQ]=derivative(x,'Vuanswer',sigma_a,alpha,b);

%don't forget to adjust the derivative for the fact that this is a
%log-linear expansion....not a linear expansion!
deru=QQ.*x;

%compute the ratio of the two types of derivatives...
rat=deruu./deru;

if (abs(rat-1)) > .0000001
    error('fatal (hmk1answer) derivatives not accurate')
end

%now, compute the log-linear expansion of the intertemporal euler equation,
%numerically
y(1)=k;
y(2)=k;
y(3)=k;
y(4)=1;
y(5)=1;
y(6)=epsilon;
y(7)=epsilon;

[eul] = Vkanswer(y,sigma_a,alpha,b,delta,sigma,beta);

if abs(eul) > .1e-9
    error('fatal (hmk1answer) dynamic euler equation not satisfied')
end
[QQ]=derivative(y,'Vkanswer',sigma_a,alpha,b,delta,sigma,beta);
%adjust for log-linear expansion...
derk=QQ.*y;

%substitute out for utilization in the intertemporal euler equation, from
%the utilization euler equation.
alpha_2=derk(1)-derk(4)*deru(1)/deru(2);
alpha_1=derk(2)-derk(5)*deru(1)/deru(2);
alpha_0=derk(3);
beta_0=derk(7)-derk(5)*deru(3)/deru(2);
beta_1=derk(6)-derk(4)*deru(3)/deru(2);

%use undetermined coefficients method to solve for A, and make sure you
%have an A that is less than unity in absolute value
dsc=-4*alpha_0*alpha_2+alpha_1^2;
if dsc<0
    error('fatal (hmk1answer) negative discriminant')
end

A=-.5*alpha_1/alpha_0 - (.5/alpha_0)*sqrt(dsc);

if abs(A) > 1
    A=-.5*alpha_1/alpha_0 + (.5/alpha_0)*sqrt(dsc);
end
if abs(A) > 1
    error('fatal (hmk1answer) failed to find non-explosive A')
end

B=-(beta_1+beta_0*rho)/(alpha_1+alpha_0*(A+rho));

chk=0;%if chk == 1, solve the same model with another code, and verify that the answer is the same
if chk == 1
    [AA,BB,Kb,cc,f3,f21,f23,f22] = solveneoclassical(beta,alpha,epsilon,delta,sigma_a,sigma,rho,1);

    if abs(A/AA-1) > .9e-4
        error('fatal (hmk1answer) problem with A')
    end

    if abs(B/BB-1) > .9e-4
        error('fatal (hmk1answer) problem with B')
    end
end

speed=log(0.10)/log(A);%this is the time needed to close 90 of the gap, in the time units of the model

Ik=(A-(1-delta))/delta;
Ieps=B/delta;
Yk=alpha;
Yeps=1;
C=epsilon*(k^alpha)-delta*k;
Ceps=(epsilon*k^alpha-k*B)/C;
Ck=(alpha*epsilon*k^alpha-k*A+(1-delta)*k)/C;
uk=-deru(1)/deru(2);
ueps=-deru(3)/deru(2);

Y=epsilon*(k^alpha);

err(1)=Yk-(C/Y)*Ck-(delta*k/Y)*Ik;
err(2)=Yeps-(C/Y)*Ceps-(delta*k/Y)*Ieps;

if max(abs(err)) > .1e-10
    error('fatal (hmk1answer) elasticity calculations fail consistency check')
end

eps=zeros(T,1);
eps(1)=.01;
z(1)=B*eps(1);%z(t) corresponds to k(t+1)
cons(1)=Ceps*eps(1);
inv(1)=Ieps*eps(1);
util(1)=ueps*eps(1);
gnp(1)=Yeps*eps(1);

for ii = 2:T

    eps(ii)=rho*eps(ii-1)+eps(ii);
    z(ii)=A*z(ii-1)+B*eps(ii);
    cons(ii)=Ck*z(ii-1)+Ceps*eps(ii);
    inv(ii)=Ik*z(ii-1)+Ieps*eps(ii);
    util(ii)=uk*z(ii-1)+ueps*eps(ii);
    gnp(ii)=Yk*z(ii-1)+Yeps*eps(ii);

end